@@ -11,7 +11,7 @@ from abc import ABCMeta, abstractmethod, abstractproperty
 from collections import defaultdict
 from functools import wraps
 
-from .promise import EmptyPromise, fulfill
+from .promise import EmptyPromise, fulfill_before
 from .safe_selenium import SafeSelenium
 
 
@@ -194,9 +194,11 @@ class PageObject(SafeSelenium):
 
         Some page objects may not provide a URL, in which case
         a `NotImplementedError` will be raised.
+
+        On success, return the page object.
         """
         if self.url is None:
-            raise NotImplementedError
+            raise NotImplementedError("Page {} does not provide a URL to visit.".format(self))
 
         # Validate the URL
         if not self.validate_url(self.url):
@@ -218,6 +220,10 @@ class PageObject(SafeSelenium):
         # Ask the page object to verify that the correct page loaded
         self._verify_page()
 
+        # Return the page object, so that the caller can chain the call with an action:
+        # Example: FooPage.visit().do_something()
+        return self
+
     @classmethod
     @unguarded
     def validate_url(cls, url):
@@ -252,16 +258,17 @@ class PageObject(SafeSelenium):
     @unguarded
     def wait_for_page(self, timeout=30):
         """
-        Block until the page loads.
+        Block until the page loads, then returns the page.
 
         Useful for ensuring that we navigate successfully to a particular page.
 
         Raises a `WebAppUIConfigError` if the page object doesn't exist.
         Raises a `BrokenPromise` exception if the page fails to load within `timeout` seconds.
         """
-        return fulfill(
-            EmptyPromise(
-                self.is_browser_on_page, "loaded page {!r}".format(self),
-                timeout=timeout
-            )
+        is_on_page_promise = EmptyPromise(
+            self.is_browser_on_page, "loaded page {!r}".format(self),
+            timeout=timeout
         )
+
+        with fulfill_before(is_on_page_promise):
+            return self
