@@ -2,11 +2,10 @@
 Base class for testing a web application.
 """
 import sys
-import time
 from unittest import TestCase
-from abc import ABCMeta, abstractproperty
+from abc import ABCMeta
 from uuid import uuid4
-from .web_app_ui import WebAppUI
+from .browser import browser, save_screenshot
 
 
 class TimeoutError(Exception):
@@ -29,43 +28,18 @@ class WebAppTest(TestCase):
 
     def setUp(self):
 
-        # Install fixtures provided by the concrete subclasses
-        # By the time this loop exits, all the test pre-conditions
-        # should be satisfied.
-        for fix in self.fixtures:
-            fix.install()
-
         # If using SauceLabs, tag the job with test info
         tags = [self.id()]
 
         # Set up the page objects
         # This will start the browser, so add a cleanup
-        self.ui = WebAppUI(self.page_object_classes, tags)
+        self.browser = browser(tags)
 
         # Cleanups are executed in LIFO order.
         # This ensures that the screenshot is taken BEFORE the browser quits.
-        self.addCleanup(self.ui.quit_browser)
+        self.addCleanup(self.browser.quit)
         self.addCleanup(self._screenshot)
 
-    @abstractproperty
-    def page_object_classes(self):
-        """
-        Subclasses override this to return a list
-        of `PageObject` subclasses to visit
-        during the test.
-        """
-        return []
-
-    @property
-    def fixtures(self):
-        """
-        Return a list of `WebAppFixture` subclasses
-        defining the pre-conditions for running the test.
-
-        Fixtures will be installed in the order provided.
-        """
-        return []
-
     @property
     def unique_id(self):
         """
@@ -85,6 +59,6 @@ class WebAppTest(TestCase):
         # or an actual exception (on error)
         if result != (None, None, None):
             try:
-                self.ui.save_screenshot(self.id())
+                save_screenshot(self.browser, self.id())
             except:
                 pass
